package com.diagbot.repository;


import com.diagbot.entity.node.ExportNode;
import com.diagbot.entity.node.ExportNodeInfo;
import org.springframework.data.neo4j.annotation.Query;
import org.springframework.data.neo4j.repository.Neo4jRepository;

import java.util.List;

public interface ExportNodeRepository extends Neo4jRepository<ExportNodeInfo, Long> {

    @Query("MATCH (n:`医保疾病名称`)-[]->(m:`医保ICD_10代码`)RETURN distinct trim(n.name) as name ,case when n.sex is not null then n.sex else '3' end as sex,case when n.age is not null then n.age else '0-200' end as ageRange,trim(m.name) as icd10Code")
    List<ExportNode> getDisease();
    @Query("MATCH (n:`医保疾病名称`) RETURN distinct trim(n.name) as name ,case when n.sex is not null then n.sex else '3' end as sex,case when n.age is not null then n.age else '0-200' end as ageRange,\"\" as icd10Code")
    List<ExportNode> getDisease2();

    @Query("MATCH (n:`药品通用名称`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getDrug();

    @Query("match (n:药品通用名称)<-[r]-(m:药品代码通用名)-[r1]->(o:药品注册名称) return distinct(trim(m.注册剂型)) as name")
    List<ExportNode> getDrugForm();

    @Query("MATCH (n:`症状`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getSymptom();

    @Query("MATCH (n:`体征`) where id(n) > 470000 or  id(n) =439877 RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getVital();

    @Query("MATCH (n:`医保手术和操作名称`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getOeration();

    @Query("MATCH (n:`实验室检查套餐名`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getLisPackage();

    @Query("MATCH (n:`实验室检查名称`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getLisItem();

    @Query("MATCH (n:`辅助检查名称`)  RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getPacs();

    @Query("MATCH (n:`辅助检查子项目名称`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getPacsSubItem();

    @Query("MATCH (n:`辅助检查名称描述`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getPacsDesc();

    @Query("MATCH (n:`辅助检查名称结果`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getPacsResult();

    @Query("MATCH (n:输血提醒指标) return distinct(trim(n.输注类型)) as name")
    List<ExportNode> getTransfusion();

    @Query("MATCH (n:`科室`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getDept();

    @Query("MATCH (n:`性别`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getSex();

    @Query("MATCH (n:`过敏原`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getAllergen();

    @Query("MATCH (n:`禁忌医疗器械及物品`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getApparatus();

    @Query("MATCH (n:`药品化学物质类别`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getDrugTypeA();

    @Query("MATCH (n:`药品治疗学类别`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getDrugTypeB();

    @Query("MATCH (n:`药品药理学类别`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getDrugTypeC();

    @Query("MATCH (n:`药品解剖学类别`) RETURN distinct(trim(n.name)) as name")
    List<ExportNode> getDrugTypeD();
}