package com.diagbot.repository;

import com.diagbot.dto.BillNeoDTO;
import com.diagbot.dto.PacsBillNeoDTO;
import com.diagbot.entity.BaseNodeInfo;
import com.diagbot.entity.node.*;
import com.diagbot.entity.relationship.*;
import com.diagbot.entity.relationship.base.BaseRelation;
import com.diagbot.entity.node.Allergen;
import com.diagbot.entity.node.BillConflictItem;
import com.diagbot.entity.node.ClinicalFinding;
import com.diagbot.entity.node.ConflictDevice;
import com.diagbot.entity.node.Disease;
import com.diagbot.entity.node.Gender;
import com.diagbot.entity.node.Group;
import com.diagbot.entity.node.Lis;
import com.diagbot.entity.node.MedAllergen;
import com.diagbot.entity.node.OralMedicine;
import com.diagbot.entity.node.PacsDescribe;
import com.diagbot.entity.node.PacsName;
import com.diagbot.entity.node.Vital;
import com.diagbot.entity.relationship.PacsNameAllergen;
import com.diagbot.entity.relationship.PacsNameBillConflictItem;
import com.diagbot.entity.relationship.PacsNameClinicalFinding;
import com.diagbot.entity.relationship.PacsNameConflictDevice;
import com.diagbot.entity.relationship.PacsNameDisease;
import com.diagbot.entity.relationship.PacsNameGender;
import com.diagbot.entity.relationship.PacsNameGroup;
import com.diagbot.entity.relationship.PacsNameLis;
import com.diagbot.entity.relationship.PacsNameMedAllergen;
import com.diagbot.entity.relationship.PacsNameOralMedicine;
import com.diagbot.entity.relationship.PacsNamePacsDescribe;
import com.diagbot.entity.relationship.PacsNameVital;
import com.diagbot.util.ListUtil;
import com.diagbot.util.NeoUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

@Component
public class PacsNameNode {

    @Autowired
    MedAllergenRepository medAllergenRepository;
    @Autowired
    GenderRepository genderRepository;
    @Autowired
    LisRepository lisRepository;
    @Autowired
    GroupRepository groupRepository;
    @Autowired
    ClinicalFindingRepository clinicalFindingRepository;
    @Autowired
    VitalRepository vitalRepository;
    @Autowired
    AgeRepository ageRepository;
    @Autowired
    DiseaseRepository diseaseRepository;
    @Autowired
    BillConflictItemRepository billConflictItemRepository;
    @Autowired
    ConflictDeviceRepository conflictDeviceRepository;
    @Autowired
    OralMedicineRepository oralMedicineRepository;
    @Autowired
    PacsDescribeRepository pacsDescribeRepository;
    @Autowired
    AllergenRepository allergenRepository;


    public PacsBillNeoDTO PacstoPACSDTO(PacsName pacs) {
        PacsBillNeoDTO pacsBillNeoDTO = new PacsBillNeoDTO();
        NodeInfo nodeInfo;


        PacsNameGender pacsNamegender = pacs.getPacsNameGender();
        if (NeoUtil.isExist(pacsNamegender)) {
            if (NeoUtil.isExist(pacsNamegender.getGender())) {
                nodeInfo = new NodeInfo();
                nodeInfo.setName(pacsNamegender.getGender().getName());
                nodeInfo.setTypeval(Constants.gender);
                pacsBillNeoDTO.setGender(NeoUtil.updateNodeInfo(nodeInfo));
            }
        }


        Set<PacsNameClinicalFinding> pacsNameclinicalfindings = pacs.getPacsNameClinicalfindings();
        for (PacsNameClinicalFinding clinicalfinding : pacsNameclinicalfindings) {
            if (NeoUtil.isExist(clinicalfinding)) {
                if (NeoUtil.isExist(clinicalfinding.getClinicalFinding())) {
                    nodeInfo = new NodeInfo();
                    nodeInfo.setName(clinicalfinding.getClinicalFinding().getName());
                    nodeInfo.setMinval(NeoUtil.DoubletoBigDecimal(clinicalfinding.getClinicalFinding().getMinval()));
                    nodeInfo.setMaxval(NeoUtil.DoubletoBigDecimal(clinicalfinding.getClinicalFinding().getMaxval()));
                    nodeInfo.setUnit(clinicalfinding.getClinicalFinding().getUnit());
                    nodeInfo.setRange(clinicalfinding.getClinicalFinding().getRange());
                    nodeInfo.setTypeval(Constants.clinicalfinding);
                    pacsBillNeoDTO.getClinicfindings().add(NeoUtil.updateNodeInfo(nodeInfo));
                }
            }
        }


        Set<PacsNameVital> pacsNamevitals = pacs.getPacsNameVitals();
        for (PacsNameVital PNvital : pacsNamevitals) {
            if (NeoUtil.isExist(PNvital)) {
                if (NeoUtil.isExist(PNvital.getVital())) {
                    nodeInfo = new NodeInfo();
                    Vital vital = PNvital.getVital();
                    String name = (vital.getVitalidx()==null)?vital.getName():vital.getVitalidx();
                    nodeInfo.setName(name);
                    nodeInfo.setMinval(NeoUtil.DoubletoBigDecimal(vital.getMinval()));
                    nodeInfo.setMaxval(NeoUtil.DoubletoBigDecimal(vital.getMaxval()));
                    nodeInfo.setUnit(vital.getUnit());
                    nodeInfo.setRange(vital.getRange());
                    nodeInfo.setTypeval(Constants.vital);
                    if (name.equals(Constants.age)) {
                        pacsBillNeoDTO.setAgeNeoDTO(NeoUtil.updateNodeInfo(nodeInfo));
                    }
                    else {
                        pacsBillNeoDTO.getVitals().add(NeoUtil.updateNodeInfo(nodeInfo));
                    }
                }
            }
        }


        Set<PacsNameLis> pacsNameliss = pacs.getPacsNameLis();
        for (PacsNameLis lis : pacsNameliss) {
            if (NeoUtil.isExist(lis)) {
                if (NeoUtil.isExist(lis.getLis())) {
                    nodeInfo = new NodeInfo();
                    nodeInfo.setName(lis.getLis().getLisidx());
                    nodeInfo.setMinval(NeoUtil.DoubletoBigDecimal(lis.getLis().getMinval()));
                    nodeInfo.setMaxval(NeoUtil.DoubletoBigDecimal(lis.getLis().getMaxval()));
                    nodeInfo.setUnit(lis.getLis().getUnit());
                    nodeInfo.setRange(lis.getLis().getRange());
                    nodeInfo.setTypeval(Constants.lis);
                    pacsBillNeoDTO.getLis().add(NeoUtil.updateNodeInfo(nodeInfo));
                }
            }
        }


        Set<PacsNamePacsDescribe> pacsNameconflict_pacsdesc = pacs.getPacsNamePacsdescribes();
        for (PacsNamePacsDescribe pacsdesc : pacsNameconflict_pacsdesc) {
            if (NeoUtil.isExist(pacsdesc)) {
                if (NeoUtil.isExist(pacsdesc.getPacsDescribe())) {
                    nodeInfo = new NodeInfo();
                    nodeInfo.setName(pacsdesc.getPacsDescribe().getName());
                    nodeInfo.setTypeval(Constants.pacsdesc);
                    pacsBillNeoDTO.getPacsDesc().add(NeoUtil.updateNodeInfo(nodeInfo));
                }
            }
        }


        Set<PacsNameGroup> pacsNamegroups = pacs.getPacsNameGroups();
        for (PacsNameGroup PNgroup : pacsNamegroups) {
            if (NeoUtil.isExist(PNgroup)) {
                if (NeoUtil.isExist(PNgroup.getGroup())) {
                    nodeInfo = new NodeInfo();
                    Group group = PNgroup.getGroup();
                    String name = (group.getGroupidx()==null)?group.getName():group.getGroupidx();
                    nodeInfo.setName(name);
                    nodeInfo.setTypeval(Constants.group);
                    pacsBillNeoDTO.getGroup().add(NeoUtil.updateNodeInfo(nodeInfo));
                }
            }
        }


        Set<PacsNameOralMedicine> pacsNameconflict_medicines = pacs.getPacsNameOralmedicines();
        for (PacsNameOralMedicine conflict_medicine : pacsNameconflict_medicines) {
            if (NeoUtil.isExist(conflict_medicine)) {
                if (NeoUtil.isExist(conflict_medicine.getOralMedicine())) {
                    nodeInfo = new NodeInfo();
                    nodeInfo.setName(conflict_medicine.getOralMedicine().getName());
                    nodeInfo.setTypeval(Constants.yaoping);
                    pacsBillNeoDTO.getOralmeds().add(NeoUtil.updateNodeInfo(nodeInfo));
                }
            }
        }


        Set<PacsNameMedAllergen> pacsNamemedAllergens = pacs.getPacsNameMedallergens();
        for (PacsNameMedAllergen medAllergen : pacsNamemedAllergens) {
            if (NeoUtil.isExist(medAllergen)) {
                if (NeoUtil.isExist(medAllergen.getMedAllergen())) {
                    nodeInfo = new NodeInfo();
                    nodeInfo.setName(medAllergen.getMedAllergen().getName());
                    nodeInfo.setTypeval(NeoUtil.getMedType(medAllergen.getMedAllergen().getName()));
                    pacsBillNeoDTO.getAllergicmeds().add(NeoUtil.updateNodeInfo(nodeInfo));
                }
            }
        }


        Set<PacsNameDisease> pacsNamediseases = pacs.getPacsNameDiseases();
        for (PacsNameDisease disease : pacsNamediseases) {
            if (NeoUtil.isExist(disease)) {
                if (NeoUtil.isExist(disease.getDisease())) {
                    nodeInfo = new NodeInfo();
                    nodeInfo.setName(disease.getDisease().getName());
                    nodeInfo.setTypeval(Constants.disease);
                    nodeInfo.setMatchtype(disease.getExactMatch());
                    pacsBillNeoDTO.getDisease().add(NeoUtil.updateNodeInfo(nodeInfo));
                }
            }
        }


        Set<PacsNameAllergen> pacsNameallergens = pacs.getPacsNameAllergens();
        for (PacsNameAllergen allergen : pacsNameallergens) {
            if (NeoUtil.isExist(allergen)) {
                if (NeoUtil.isExist(allergen.getAllergen())) {
                    nodeInfo = new NodeInfo();
                    nodeInfo.setName(allergen.getAllergen().getName());
                    nodeInfo.setTypeval(Constants.yaoping); // 过敏原归类成药物过敏原，与模型提取匹配
                    pacsBillNeoDTO.getAllergicmeds().add(NeoUtil.updateNodeInfo(nodeInfo));
                }
            }
        }


        Set<PacsNameConflictDevice> pacsNameconflictDevices = pacs.getPacsNameConflictdevices();
        for (PacsNameConflictDevice conflictDevice : pacsNameconflictDevices) {
            if (NeoUtil.isExist(conflictDevice)) {
                if (NeoUtil.isExist(conflictDevice.getConflictDevice())) {
                    nodeInfo = new NodeInfo();
                    nodeInfo.setName(conflictDevice.getConflictDevice().getName());
                    nodeInfo.setTypeval(Constants.conflictdevice);
                    pacsBillNeoDTO.getMeddevice().add(NeoUtil.updateNodeInfo(nodeInfo));
                }
            }
        }

        /*
        Set<PacsNamePacsName> pacsNamepacsNames = pacs.getConflictPacsName_out();
        for (PacsNamePacsName pacsName : pacsNamepacsNames) {
            if (NeoUtil.isExist(pacsName)) {
                if (NeoUtil.isExist(pacsName.getConflict_pacsName())) {
                    nodeInfo = new NodeInfo();
                    nodeInfo.setName(pacsName.getConflict_pacsName().getName());
                    nodeInfo.setTypeval(Constants.fujian);
                    pacsBillNeoDTO.getPacsOrder().add(NeoUtil.updateNodeInfo(nodeInfo));
                }
            }
        }
        */

        Set<PacsNameBillConflictItem> pacsNameBillConflictItems = pacs.getPacsNameBillConflictItems();
        for (PacsNameBillConflictItem pacsNameBill : pacsNameBillConflictItems) {
            if (NeoUtil.isExist(pacsNameBill)) {
                if (NeoUtil.isExist(pacsNameBill.getBillConflictItem())) {
                    nodeInfo = new NodeInfo();
                    nodeInfo.setName(pacsNameBill.getBillConflictItem().getName());
                    nodeInfo.setTypeval(Constants.fujian);
                    pacsBillNeoDTO.getPacsOrder().add(NeoUtil.updateNodeInfo(nodeInfo));
                }
            }
        }

        return pacsBillNeoDTO;
    }


    /**
     * 处理辅检开单合理性
     */
    public List<BillNeoDTO> getPacsBill(List<Map<String, String>> pacslist, PacsNameRepository pacsRepository) {
        List<BillNeoDTO> billNeoDTOs = new ArrayList<>();
        BillNeoDTO billNeoDTO;

        PacsBillNeoDTO pacsBillNeoDTO;

        List<PacsName> pacslt;
        String pacsname;

        for (Map<String, String> pacsterm : pacslist) {
            for (String term : pacsterm.keySet()) {
                billNeoDTO = new BillNeoDTO();
                pacsname = pacsterm.get(term);
                billNeoDTO.setName(term);
                billNeoDTO.setStandname(pacsname);

                pacsBillNeoDTO = new PacsBillNeoDTO();

                pacslt = pacsRepository.findByNameIs(pacsname);

                if (ListUtil.isNotEmpty(pacslt)) {
                    pacsBillNeoDTO = PacstoPACSDTO(pacslt.get(0));
                    billNeoDTO.setPacsBillNeoDTO(pacsBillNeoDTO);

                    billNeoDTOs.add(billNeoDTO);
                }
            }
        }

        return billNeoDTOs;
    }


    /**
     * 获取辅检名称列表
     */
    public List<String> getPACSNameList(String name, PacsNameRepository pacsRepository) {
        String pacsname;

        List<String> pacslist = new ArrayList<>();

        List<PacsName> pacslt = pacsRepository.index(name, name, 100);

        if (ListUtil.isNotEmpty(pacslt) && pacslt.size() > 100) {
            pacslt = pacslt.subList(0, 100);
        }

        for (PacsName pacs : pacslt) {
            pacsname = pacs.getName();
            if (!pacslist.contains(pacsname)) {
                pacslist.add(pacsname);
            }
        }

        return pacslist;
    }


    /**
     * 获取辅检名称列表
     */
    public List<String> getPACSNameAndPACSSubNameList(String name, Integer size, PacsNameRepository pacsRepository) {

        List<String> pacslist = new ArrayList<>();
        if (null == size) {
            size = 100;
        }
        List<BaseNodeInfo> pacslt = pacsRepository.indexMultipleLabel(name, name, size);

        if (ListUtil.isNotEmpty(pacslt) && pacslt.size() > size) {
            pacslt = pacslt.subList(0, size);
        }

        pacslist = pacslt.stream().map(i -> i.getName()).collect(Collectors.toList());

        return pacslist;
    }


    /**
     * 获取辅检及子项目名称列表
     */
    public List<String> getPACSNameAndPACSSubNames(String name, Integer size, PacsNameRepository pacsRepository) {

        List<String> pacslist;
        if (null == size || size == 0) {
            size = Constants.termsize;
        }

        pacslist = pacsRepository.getPACSNames(size);

        return pacslist;
    }


    /**
     * 根据关系名查询对应节点
     */
    public List<?> getNodesbyRelation(PacsName pacsName, String relname) {
        List<?> nodelist = new ArrayList<>();

        try {
            switch (relname) {
                case "辅助检查名称禁忌性别":
                    nodelist = Arrays.asList(pacsName.getPacsNameGender().getGender());
                    break;
                case "辅助检查名称禁忌临床表现":
                    nodelist = pacsName.getPacsNameClinicalfindings().stream().map(x -> x.getClinicalFinding()).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌体征":
                    nodelist = pacsName.getPacsNameVitals().stream().map(x -> x.getVital()).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌实验室检查":
                    nodelist = pacsName.getPacsNameLis().stream().map(x -> x.getLis()).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌辅助检查名称描述":
                    nodelist = pacsName.getPacsNamePacsdescribes().stream().map(x -> x.getPacsDescribe()).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌禁忌人群":
                    nodelist = pacsName.getPacsNameGroups().stream().map(x -> x.getGroup()).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌服用药品":
                    nodelist = pacsName.getPacsNameOralmedicines().stream().map(x -> x.getOralMedicine()).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌药物过敏原":
                    nodelist = pacsName.getPacsNameMedallergens().stream().map(x -> x.getMedAllergen()).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌疾病":
                    nodelist = pacsName.getPacsNameDiseases().stream().map(x -> x.getDisease()).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌过敏原":
                    nodelist = pacsName.getPacsNameAllergens().stream().map(x -> x.getAllergen()).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌禁忌医疗器械及物品":
                    nodelist = pacsName.getPacsNameConflictdevices().stream().map(x -> x.getConflictDevice()).collect(Collectors.toList());
                    break;
            }
        } catch (Exception ex) {
            ex.printStackTrace();
        } finally {
            return nodelist;
        }
    }


    /**
     * 更新关系状态属性
     */
    public void updateRelation(PacsName pacsName, String relname, Integer status, String e_name, PacsNameRepository pacsNameRepository) {

        try {
            switch (relname) {
                case "辅助检查名称禁忌性别":
                    pacsName.getPacsNameGender().setStatus(status);
                    pacsNameRepository.save(pacsName);
                    break;
                case "辅助检查名称禁忌临床表现":
                    pacsName.getPacsNameClinicalfindings().stream().filter(x -> x.getClinicalFinding().getName() == e_name).
                            collect(Collectors.toList()).stream().forEach(y -> y.setStatus(status));
                    pacsNameRepository.save(pacsName);
                    break;
                case "辅助检查名称禁忌体征":
                    List<PacsNameVital> pacsNameVitals = pacsName.getPacsNameVitals().stream().filter(x -> x.getVital().getName() == e_name).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌实验室检查":
                    List<PacsNameLis> pacsNameLis = pacsName.getPacsNameLis().stream().filter(x -> x.getLis().getName() == e_name).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌辅助检查名称描述":
                    List<PacsNamePacsDescribe> pacsNamePacsDescribes = pacsName.getPacsNamePacsdescribes().stream().filter(x -> x.getPacsDescribe().getName() == e_name).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌禁忌人群":
                    List<PacsNameGroup> pacsNameGroups = pacsName.getPacsNameGroups().stream().filter(x -> x.getGroup().getName() == e_name).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌服用药品":
                    List<PacsNameOralMedicine> pacsNameOralMedicines = pacsName.getPacsNameOralmedicines().stream().filter(x -> x.getOralMedicine().getName() == e_name).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌药物过敏原":
                    List<PacsNameMedAllergen> pacsNameMedAllergens = pacsName.getPacsNameMedallergens().stream().filter(x -> x.getMedAllergen().getName() == e_name).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌疾病":
                    List<PacsNameDisease> pacsNameDiseases = pacsName.getPacsNameDiseases().stream().filter(x -> x.getDisease().getName() == e_name).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌过敏原":
                    List<PacsNameAllergen> pacsNameAllergens = pacsName.getPacsNameAllergens().stream().filter(x -> x.getAllergen().getName() == e_name).collect(Collectors.toList());
                    break;
                case "辅助检查名称禁忌禁忌医疗器械及物品":
                    List<PacsNameConflictDevice> pacsNameConflictDevices = pacsName.getPacsNameConflictdevices().stream().filter(x -> x.getConflictDevice().getName() == e_name).collect(Collectors.toList());
                    break;
            }
        } catch (Exception ex) {
            ex.printStackTrace();
        } finally {

        }
    }

    /**
     * 更新关系状态属性
     */
    public void updateRelationExt(PacsName pacsName, String relname, Integer status, Integer ruleType, String e_name, PacsNameRepository pacsNameRepository) {
        Boolean isExist = false;
        try {
            switch (relname) {
                case "辅助检查名称禁忌性别":
                    Gender gender = genderRepository.findByNameIs(e_name).get(0);
                    PacsNameGender pacsNameGender = new PacsNameGender();
                    pacsNameGender.setGender(gender);
                    pacsNameGender.setPacsName(pacsName);
                    pacsNameGender.setStatus(status);
                    pacsNameGender.setRuleType(ruleType);
                    pacsName.setPacsNameGender(pacsNameGender);
                    pacsNameRepository.save(pacsName, 1);
                    break;
                case "辅助检查名称禁忌禁忌人群":
                    Group group = groupRepository.findByNameIs(e_name).get(0);
                    Set<PacsNameGroup> pacsNameGroupSet = pacsName.getPacsNameGroups();
                    isExist = false;
                    for (PacsNameGroup item : pacsNameGroupSet) {
                        if (item.getGroup() != null
                                && item.getGroup().getName().equals(e_name)) {
                            isExist = true;
                            item.setPacsName(pacsName);
                            item.setGroup(group);
                            item.setStatus(status);
                            item.setRuleType(ruleType);
                        }
                    }
                    if (!isExist) {
                        PacsNameGroup pacsNameGroup = new PacsNameGroup();
                        pacsNameGroup.setGroup(group);
                        pacsNameGroup.setPacsName(pacsName);
                        pacsNameGroup.setStatus(status);
                        pacsNameGroup.setRuleType(ruleType);
                        pacsNameGroupSet.add(pacsNameGroup);
                    }
                    pacsName.setPacsNameGroups(pacsNameGroupSet);
                    pacsNameRepository.save(pacsName, 1);
                    break;
                case "辅助检查名称禁忌药物过敏原":
                    MedAllergen medAllergen = medAllergenRepository.findByNameIs(e_name).get(0);
                    Set<PacsNameMedAllergen> pacsNameMedAllergenSet = pacsName.getPacsNameMedallergens();
                    isExist = false;
                    for (PacsNameMedAllergen item : pacsNameMedAllergenSet) {
                        if (item.getMedAllergen() != null
                                && item.getMedAllergen().getName().equals(e_name)) {
                            isExist = true;
                            item.setPacsName(pacsName);
                            item.setMedAllergen(medAllergen);
                            item.setStatus(status);
                            item.setRuleType(ruleType);
                        }
                    }
                    if (!isExist) {
                        PacsNameMedAllergen pacsNameMedAllergen = new PacsNameMedAllergen();
                        pacsNameMedAllergen.setMedAllergen(medAllergen);
                        pacsNameMedAllergen.setPacsName(pacsName);
                        pacsNameMedAllergen.setStatus(status);
                        pacsNameMedAllergen.setRuleType(ruleType);
                        pacsNameMedAllergenSet.add(pacsNameMedAllergen);
                    }
                    pacsName.setPacsNameMedallergens(pacsNameMedAllergenSet);
                    pacsNameRepository.save(pacsName, 1);
                    break;
                case "辅助检查名称禁忌临床表现":
                    ClinicalFinding clinicalFinding = clinicalFindingRepository.findByNameIs(e_name).get(0);
                    Set<PacsNameClinicalFinding> pacsNameClinicalFindingSet = pacsName.getPacsNameClinicalfindings();
                    isExist = false;
                    for (PacsNameClinicalFinding item : pacsNameClinicalFindingSet) {
                        if (item.getClinicalFinding() != null
                                && item.getClinicalFinding().getName().equals(e_name)) {
                            isExist = true;
                            item.setPacsName(pacsName);
                            item.setClinicalFinding(clinicalFinding);
                            item.setStatus(status);
                            item.setRuleType(ruleType);
                        }
                    }
                    if (!isExist) {
                        PacsNameClinicalFinding pacsNameClinicalFinding = new PacsNameClinicalFinding();
                        pacsNameClinicalFinding.setClinicalFinding(clinicalFinding);
                        pacsNameClinicalFinding.setPacsName(pacsName);
                        pacsNameClinicalFinding.setStatus(status);
                        pacsNameClinicalFinding.setRuleType(ruleType);
                        pacsNameClinicalFindingSet.add(pacsNameClinicalFinding);
                    }
                    pacsName.setPacsNameClinicalfindings(pacsNameClinicalFindingSet);
                    pacsNameRepository.save(pacsName, 1);
                    break;
                case "辅助检查名称禁忌实验室检查名称":
                    break;
                case "辅助检查名称禁忌实验室检查":
                    Lis lis = lisRepository.findByNameIs(e_name).get(0);
                    Set<PacsNameLis> pacsNameLisSet = pacsName.getPacsNameLis();
                    isExist = false;
                    for (PacsNameLis item : pacsNameLisSet) {
                        if (item.getLis() != null
                                && item.getLis().getName().equals(e_name)) {
                            isExist = true;
                            item.setPacsName(pacsName);
                            item.setLis(lis);
                            item.setStatus(status);
                            item.setRuleType(ruleType);
                        }
                    }
                    if (!isExist) {
                        PacsNameLis pacsNameLis = new PacsNameLis();
                        pacsNameLis.setLis(lis);
                        pacsNameLis.setPacsName(pacsName);
                        pacsNameLis.setStatus(status);
                        pacsNameLis.setRuleType(ruleType);
                        pacsNameLisSet.add(pacsNameLis);
                    }
                    pacsName.setPacsNameLis(pacsNameLisSet);
                    pacsNameRepository.save(pacsName, 1);
                    break;
                case "辅助检查名称禁忌疾病":
                    Disease disease = diseaseRepository.findByNameIs(e_name).get(0);
                    Set<PacsNameDisease> pacsNameDiseaseSet = pacsName.getPacsNameDiseases();
                    isExist = false;
                    for (PacsNameDisease item : pacsNameDiseaseSet) {
                        if (item.getDisease() != null
                                && item.getDisease().getName().equals(e_name)) {
                            isExist = true;
                            item.setPacsName(pacsName);
                            item.setDisease(disease);
                            item.setStatus(status);
                            item.setRuleType(ruleType);
                        }
                    }
                    if (!isExist) {
                        PacsNameDisease pacsNameDisease = new PacsNameDisease();
                        pacsNameDisease.setDisease(disease);
                        pacsNameDisease.setPacsName(pacsName);
                        pacsNameDisease.setStatus(status);
                        pacsNameDisease.setRuleType(ruleType);
                        pacsNameDiseaseSet.add(pacsNameDisease);
                    }
                    pacsName.setPacsNameDiseases(pacsNameDiseaseSet);
                    pacsNameRepository.save(pacsName, 1);
                    break;
                case "辅助检查名称禁忌禁忌医疗器械及物品":
                    ConflictDevice conflictDevice = conflictDeviceRepository.findByNameIs(e_name).get(0);
                    Set<PacsNameConflictDevice> pacsNameConflictDeviceSet = pacsName.getPacsNameConflictdevices();
                    isExist = false;
                    for (PacsNameConflictDevice item : pacsNameConflictDeviceSet) {
                        if (item.getConflictDevice() != null
                                && item.getConflictDevice().getName().equals(e_name)) {
                            isExist = true;
                            item.setPacsName(pacsName);
                            item.setConflictDevice(conflictDevice);
                            item.setStatus(status);
                            item.setRuleType(ruleType);
                        }
                    }
                    if (!isExist) {
                        PacsNameConflictDevice pacsNameConflictDevice = new PacsNameConflictDevice();
                        pacsNameConflictDevice.setConflictDevice(conflictDevice);
                        pacsNameConflictDevice.setPacsName(pacsName);
                        pacsNameConflictDevice.setStatus(status);
                        pacsNameConflictDevice.setRuleType(ruleType);
                        pacsNameConflictDeviceSet.add(pacsNameConflictDevice);
                    }
                    pacsName.setPacsNameConflictdevices(pacsNameConflictDeviceSet);
                    pacsNameRepository.save(pacsName, 1);
                    break;
                case "辅助检查名称禁忌体征":
                    Vital vital = vitalRepository.findByNameIs(e_name).get(0);
                    Set<PacsNameVital> pacsNameVitalSet = pacsName.getPacsNameVitals();
                    isExist = false;
                    for (PacsNameVital item : pacsNameVitalSet) {
                        if (item.getVital() != null
                                && item.getVital().getName().equals(e_name)) {
                            isExist = true;
                            item.setPacsName(pacsName);
                            item.setVital(vital);
                            item.setStatus(status);
                            item.setRuleType(ruleType);
                        }
                    }
                    if (!isExist) {
                        PacsNameVital pacsNameVital = new PacsNameVital();
                        pacsNameVital.setVital(vital);
                        pacsNameVital.setPacsName(pacsName);
                        pacsNameVital.setStatus(status);
                        pacsNameVital.setRuleType(ruleType);
                        pacsNameVitalSet.add(pacsNameVital);
                    }
                    pacsName.setPacsNameVitals(pacsNameVitalSet);
                    pacsNameRepository.save(pacsName, 1);
                    break;
                case "辅助检查名称禁忌服用药品":
                    OralMedicine oralMedicine = oralMedicineRepository.findByNameIs(e_name).get(0);
                    Set<PacsNameOralMedicine> pacsNameOralMedicineSet = pacsName.getPacsNameOralmedicines();
                    isExist = false;
                    for (PacsNameOralMedicine item : pacsNameOralMedicineSet) {
                        if (item.getOralMedicine() != null
                                && item.getOralMedicine().getName().equals(e_name)) {
                            isExist = true;
                            item.setPacsName(pacsName);
                            item.setOralMedicine(oralMedicine);
                            item.setStatus(status);
                            item.setRuleType(ruleType);
                        }
                    }
                    if (!isExist) {
                        PacsNameOralMedicine pacsNameOralMedicine = new PacsNameOralMedicine();
                        pacsNameOralMedicine.setOralMedicine(oralMedicine);
                        pacsNameOralMedicine.setPacsName(pacsName);
                        pacsNameOralMedicine.setStatus(status);
                        pacsNameOralMedicine.setRuleType(ruleType);
                        pacsNameOralMedicineSet.add(pacsNameOralMedicine);
                    }
                    pacsName.setPacsNameOralmedicines(pacsNameOralMedicineSet);
                    pacsNameRepository.save(pacsName, 1);
                    break;
                case "辅助检查名称禁忌辅助检查名称描述":
                    PacsDescribe pacsDescribe = pacsDescribeRepository.findByNameIs(e_name).get(0);
                    Set<PacsNamePacsDescribe> pacsNamePacsDescribeSet = pacsName.getPacsNamePacsdescribes();
                    isExist = false;
                    for (PacsNamePacsDescribe item : pacsNamePacsDescribeSet) {
                        if (item.getPacsDescribe() != null
                                && item.getPacsDescribe().getName().equals(e_name)) {
                            isExist = true;
                            item.setPacsName(pacsName);
                            item.setPacsDescribe(pacsDescribe);
                            item.setStatus(status);
                            item.setRuleType(ruleType);
                        }
                    }
                    if (!isExist) {
                        PacsNamePacsDescribe pacsNamePacsDescribe = new PacsNamePacsDescribe();
                        pacsNamePacsDescribe.setPacsDescribe(pacsDescribe);
                        pacsNamePacsDescribe.setPacsName(pacsName);
                        pacsNamePacsDescribe.setStatus(status);
                        pacsNamePacsDescribe.setRuleType(ruleType);
                        pacsNamePacsDescribeSet.add(pacsNamePacsDescribe);
                    }
                    pacsName.setPacsNamePacsdescribes(pacsNamePacsDescribeSet);
                    pacsNameRepository.save(pacsName, 1);
                    break;
                case "辅助检查名称禁忌过敏原":
                    Allergen allergen = allergenRepository.findByNameIs(e_name).get(0);
                    Set<PacsNameAllergen> pacsNameAllergenSet = pacsName.getPacsNameAllergens();
                    isExist = false;
                    for (PacsNameAllergen item : pacsNameAllergenSet) {
                        if (item.getAllergen() != null
                                && item.getAllergen().getName().equals(e_name)) {
                            isExist = true;
                            item.setPacsName(pacsName);
                            item.setAllergen(allergen);
                            item.setStatus(status);
                            item.setRuleType(ruleType);
                        }
                    }
                    if (!isExist) {
                        PacsNameAllergen pacsNameAllergen = new PacsNameAllergen();
                        pacsNameAllergen.setAllergen(allergen);
                        pacsNameAllergen.setPacsName(pacsName);
                        pacsNameAllergen.setStatus(status);
                        pacsNameAllergen.setRuleType(ruleType);
                        pacsNameAllergenSet.add(pacsNameAllergen);
                    }
                    pacsName.setPacsNameAllergens(pacsNameAllergenSet);
                    pacsNameRepository.save(pacsName, 1);
                    break;
                case "辅助检查名称禁忌开单项互斥":
                    BillConflictItem billConflictItem = billConflictItemRepository.findByNameIs(e_name).get(0);
                    Set<PacsNameBillConflictItem> pacsNameBillConflictItemSet = pacsName.getPacsNameBillConflictItems();
                    isExist = false;
                    for (PacsNameBillConflictItem item : pacsNameBillConflictItemSet) {
                        if (item.getBillConflictItem() != null
                                && item.getBillConflictItem().getName().equals(e_name)) {
                            isExist = true;
                            item.setPacsName(pacsName);
                            item.setBillConflictItem(billConflictItem);
                            item.setStatus(status);
                            item.setRuleType(ruleType);
                        }
                    }
                    if (!isExist) {
                        PacsNameBillConflictItem pacsNameBillConflictItem = new PacsNameBillConflictItem();
                        pacsNameBillConflictItem.setBillConflictItem(billConflictItem);
                        pacsNameBillConflictItem.setPacsName(pacsName);
                        pacsNameBillConflictItem.setStatus(status);
                        pacsNameBillConflictItem.setRuleType(ruleType);
                        pacsNameBillConflictItemSet.add(pacsNameBillConflictItem);
                    }
                    pacsName.setPacsNameBillConflictItems(pacsNameBillConflictItemSet);
                    pacsNameRepository.save(pacsName, 1);
                    break;
            }
        } catch (Exception ex) {
            ex.printStackTrace();
        } finally {

        }
    }
}






